### 0.9.4

```{rubric} Features
```
* {func}`~rapids_singlecell.tl.leiden` now provides `random_state` parameter for initializing the optimization {pr}`102` {smaller}`J Pintar & S Dicks`
* {func}`~rapids_singlecell.tl.louvain` now provides `threshold` parameter for setting the minimum modularity gain between levels {pr}`103` {smaller}`J Pintar & S Dicks`
* added a kernel for sparse sum along the major axis {pr}`112` {smaller}`S Dicks`
* {func}`~rapids_singlecell.pp.calculate_qc_metrics` now uses less atomics and global memory during kernels {pr}`113` {smaller}`S Dicks`
